@@ -1,10 +1,22 @@
 `dea.bcc.oo.mul` <-
-function (X, Y) {
+function (X, Y, pslv = FALSE , dual = FALSE , infor = FALSE ) {
   
   X <- .primera (X);
   Y <- .segunda (Y);
   .check(X,Y);
   
+  pslv <- as.logical (pslv );
+  presolver <- 0;
+  if ( pslv ) presolver <- 1;
+
+  dual <- as.logical ( dual );
+  dual.simplex <- 0;
+  if ( dual ) dual.simplex <- 1;
+  
+  infor <- as.logical ( infor );
+  information <- 0;
+  if ( infor ) information <- 1;
+  
   nombre.DMUs <- row.names(X);
   nombre.inputs <- names(X);
   nombre.outputs <- names(Y);
@@ -28,6 +40,9 @@ function (X, Y) {
               as.integer (num.outputs),
               as.double (XX),
               as.double (YY),
+	      as.integer (presolver),
+              as.integer (dual.simplex),
+              as.integer (information),
               salida = as.double (ZZ),
 	      PACKAGE = "DEA");
 
